==> nextcloud-app-spreed-1%3A19.0.8-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/ka_GE.js <==
OC.L10N.register(
    "spreed",
    {
    "(Duration %s)" : "(ხანგრძლივობა %s)",
    "You attended a call with {user1}" : "თქვენ დაესწარით ზარს მომხმარებელთან {user1}",
    "_%n guest_::_%n guests_" : ["%n სტუმრები","%n სტუმრები"],
    "You attended a call with {user1} and {user2}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1} და {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1}, {user2} და {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1}, {user2}, {user3} და {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1}, {user2}, {user3}, {user4} და {user5}",
    "_%n other_::_%n others_" : ["%n სხვა","%n სხვა"],
    "{actor} invited you to {call}" : "მოწვევა {call} ზარზე მომხმარებლისგან {actor}",
    "Talk" : "საუბარი",
    "Guest" : "სტუმარი",
    "Talk to %s" : "საუბარი მომხმარებელთან %s",
    "File is too big" : "ფაილი ზედმეტად დიდია",
    "Invalid file provided" : "არასწორი ფაილი",
    "Invalid image" : "არასწორი სურათი",
    "Unknown filetype" : "ამოუცნობი ფაილის ტიპი",
    "Accept" : "მიღება",
    "Decline" : "ურაყოფა",
    "Join call" : "შეუერთდით ზარს",
    "A group call has started in {call}" : "ჯგუფური ზარი დაიწყო {call}-ში",
    "Open settings" : "პარამეტრების გახსნა",
    "Avatar image is not square" : "ავატარის სურათი არაა კვადრატი",
    "Invalid date, date format must be YYYY-MM-DD" : "არასწორი თარიღი, თარიღის ფორმატი უნდა იყოს წწწწ-თთ-დდ",
    "Leave call" : "ზარის დატოვება",
    "Limit to groups" : "ლიმიტი ჯგუფებზე",
    "Everyone" : "ყველა",
    "Save changes" : "ცვილებების შენახვა",
    "Saved!" : "შენახულია!",
    "Name" : "სახელი",
    "Description" : "აღწერილობა",
    "Enabled" : "მოქმედია",
    "Disabled" : "არაა მოქმედი",
    "Federation" : "ფედერაცია",
    "Permissions" : "უფლებები",
    "General settings" : "მთავარი პარამეტრები",
    "Language" : "ენა",
    "Country" : "ქვეყანა",
    "Status" : "სტატუსი",
    "Created at" : "შეიქმნა",
    "Pending" : "მოლოდინში",
    "Error" : "შეცდომა",
    "Blocked" : "დაბლოკილია",
    "Expired" : "გაუქმდა",
    "Validate SSL certificate" : "SSL სერტიფიკატის ვალიდაცია",
    "Shared secret" : "გაზიარებული საიდუმლო",
    "STUN servers" : "STUN სერვერები",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN სერვერი როუტერს მიღმა მყოფი მონაწილეების ღია IP მისამართების დადგენისთვის.",
    "TURN server protocols" : "TURN სერვერის პროტოკოლები",
    "OK" : "კარგი",
    "Checking …" : "მოწმდება ...",
    "Back" : "უკან",
    "Cancel" : "უარყოფა",
    "Confirm" : "დადასტურება",
    "Reset" : "საწყის მდოგმარეობაში დაბრუნება",
    "Copy link" : "ბმულის კოპირება",
    "Waiting for others to join the call …" : "ზარში შემოსვლისთვის ველოდებით სხვებს …",
    "You can invite others in the participant tab of the sidebar" : "შეგიძლიათ სხვები მოიწვიოთ გვერდით ბარში, მონაწილებიის ტაბულით",
    "Share this link to invite others!" : "სხვების მოსაწვევად გააზიარეთ ეს ბმული!",
    "Mute audio" : "ხმის ჩახშობა",
    "Disable video" : "ვიდეოს გათიშვა",
    "Enable video" : "ვიდეოს ამოქმედება",
    "You" : "თქვენ",
    "Show screen" : "ეკრანის ჩვენება",
    "Collapse" : "აკეცვა",
    "Favorite" : "რჩეული",
    "Hide details" : "დეტალების დამალვა",
    "Disable" : "გამორთვა",
    "Choose" : "აირჩიეთ",
    "Restricted" : "აკრძალული",
    "Personal" : "პირადი",
    "Yes" : "დიახ",
    "Password protection" : "პაროლით თავდაცვა",
    "Save" : "შენახვა",
    "Edit" : "შეცვლა",
    "Delete" : "წაშლა",
    "Log content" : "ლოგის მოცულობა",
    "User" : "მომხმარებელი",
    "Password" : "პაროლი",
    "API token" : "API ტოკენი",
    "Login" : "ავტორიზაცია",
    "Nickname" : "ნიკნეიმი",
    "Client ID" : "კლიენტის ID",
    "Notifications" : "შეტყობინებები",
    "Mark as read" : "წაკითხულად მონიშვნა",
    "Mark as unread" : "წაუკითხავად მონიშვნა",
    "Remove from favorites" : "რჩეულებიდან ამოშლა",
    "Add to favorites" : "რჩეულებში დამატება",
    "Users" : "მომხმარებლები",
    "Groups" : "ჯგუფები",
    "Loading" : "იტვირთება",
    "None" : "არც ერთი",
    "Devices" : "მოწყობილობები",
    "Upload" : "ატვირთვა",
    "Files" : "ფაილები",
    "Message sent" : "წერილი გაგზავნილია",
    "Reply" : "პასუხი",
    "Translate" : "გადათარგმნეთ",
    "Dismiss" : "დათხოვნა",
    "Contact" : "კონტაქტი",
    "Today" : "დღეს",
    "Yesterday" : "გუშინ",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "_%n day ago_::_%n days ago_" : ["%n დღის წინ","%n დღის წინ"],
    "Close" : "დახურვა",
    "Password protect" : "პაროლით დაცვა",
    "Group" : "ჯგუფი",
    "Create new poll" : "ახალი გამოკითხვის შექმნა",
    "Settings" : "პარამეტრები",
    "Create poll" : "გამოკითხვის შექმნა",
    "Send" : "გაგზავნა",
    "moderator" : "მოდერატორი",
    "Demote from moderator" : "ჩამოიქვეითება მოდერატორობისგან",
    "Promote to moderator" : "დაწინაურება მოდერატორობაზე",
    "Remove participant" : "მონაწილის ამოშლა",
    "No results" : "შედეგები არაა",
    "Add users or groups" : "დაამატეთ მომხმარებლები ან ჯგუფები",
    "Participants" : "მონაწილეები",
    "Chat" : "ჩეთი",
    "Details" : "დეტალები",
    "Privacy" : "კონფიდენციალურობა",
    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
    "Search" : "ძიება",
    "Show your screen" : "თქვენი ეკრანის ჩვენება",
    "Stop screensharing" : "ეკრანის გაზიარების გათიშვა",
    "Screensharing options" : "ეკრანების გაზიარების პარამეტრები",
    "Enable screensharing" : "ეკრანების გაზიარების ნების დართვა",
    "Screensharing requires the page to be loaded through HTTPS." : "ეკრანების გაზიარება საჭიროებს გვერდის HTTPS პროტოკოლით ჩატვირთვას.",
    "Sharing your screen only works with Firefox version 52 or newer." : "ეკრანის გაზიარება მოქმედია Firefox-ის მხოლოდ 52 ვერსიით ან უფრო ახლით.",
    "Screensharing extension is required to share your screen." : "ეკრანების გასაზიარებლად საჭიროა გაფართოება.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "ეკრანის გასაზიარებლად გამოიყენეთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი.",
    "An error occurred while starting screensharing." : "ეკრანის გაზიარებისას წარმოიშვა შეცდომა.",
    "Grid view" : "ბადისებური ხედი",
    "Submit" : "გაგზავნა",
    "Polls" : "გამოკითხვები",
    "Audio" : "აუდიო",
    "Other" : "სხვა",
    "Default" : "საწყისი",
    "Access to microphone & camera is only possible with HTTPS" : "წვდომა მიკროფონთან და კამერასთან მხარდაჭერილია მხოლოდ HTTPS პროტოკოლით",
    "Access to microphone & camera was denied" : "წვდომა მიკროფონზე და კამერაზე აიკრძალა",
    "WebRTC is not supported in your browser" : "თქვენი ბრაუზერი WebRTC-ს არ უჭერს მხარს",
    "Please use a different browser like Firefox or Chrome" : "გთხოვთ გამოიყენოთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი",
    "Error while accessing microphone & camera" : "მიკროფონზე და კამერაზე წვდომისას წარმოიშვა შეცდომა",
    "The password is wrong. Try again." : "პაროლი არასწორია. სცადეთ ახლიდან.",
    "Android app" : "Android აპლიკაცია",
    "iOS app" : "iOS აპლიკაცია",
    "Circles" : "წრეები",
    "TURN server" : "TURN სერვერი",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN სერვერი გამოიყენება ფაირვოლს უკან მყოფი მონაწილეების ტრეფიკის რწმუნებულებების გადასაცემად.",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "დიდი ინსტალაციებისთვის შესაძლებელია გარე სასიგნალო სერვერის გამოყენება. შიდა სიგნალის სერვერის გამოსაყენებლად დატოვეთ ცარიელი."
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-app-spreed-1%3A21.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/ka_GE.js <==
OC.L10N.register(
    "spreed",
    {
    "(Duration %s)" : "(ხანგრძლივობა %s)",
    "You attended a call with {user1}" : "თქვენ დაესწარით ზარს მომხმარებელთან {user1}",
    "_%n guest_::_%n guests_" : ["%n სტუმრები","%n სტუმრები"],
    "You attended a call with {user1} and {user2}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1} და {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1}, {user2} და {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1}, {user2}, {user3} და {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1}, {user2}, {user3}, {user4} და {user5}",
    "_%n other_::_%n others_" : ["%n სხვა","%n სხვა"],
    "{actor} invited you to {call}" : "მოწვევა {call} ზარზე მომხმარებლისგან {actor}",
    "Talk" : "საუბარი",
    "Guest" : "სტუმარი",
    "Administration" : "ადმინისტრაცია",
    "System" : "სისტემა",
    "Talk to %s" : "საუბარი მომხმარებელთან %s",
    "File is too big" : "ფაილი ზედმეტად დიდია",
    "Invalid file provided" : "არასწორი ფაილი",
    "Invalid image" : "არასწორი სურათი",
    "Unknown filetype" : "ამოუცნობი ფაილის ტიპი",
    "Accept" : "მიღება",
    "Decline" : "ურაყოფა",
    "Join call" : "შეუერთდით ზარს",
    "A group call has started in {call}" : "ჯგუფური ზარი დაიწყო {call}-ში",
    "Open settings" : "პარამეტრების გახსნა",
    "Avatar image is not square" : "ავატარის სურათი არაა კვადრატი",
    "Federation" : "ფედერაცია",
    "Invalid date, date format must be YYYY-MM-DD" : "არასწორი თარიღი, თარიღის ფორმატი უნდა იყოს წწწწ-თთ-დდ",
    "Leave call" : "ზარის დატოვება",
    "Everyone" : "ყველა",
    "Save changes" : "ცვილებების შენახვა",
    "Saved!" : "შენახულია!",
    "Limit to groups" : "ლიმიტი ჯგუფებზე",
    "Enabled" : "მოქმედია",
    "Disabled" : "არაა მოქმედი",
    "Name" : "სახელი",
    "Description" : "აღწერილობა",
    "Permissions" : "უფლებები",
    "General settings" : "მთავარი პარამეტრები",
    "Enable encryption" : "შიფრაციის ამოქმედება",
    "Pending" : "მოლოდინში",
    "Error" : "შეცდომა",
    "Blocked" : "დაბლოკილია",
    "Expired" : "გაუქმდა",
    "Language" : "ენა",
    "Country" : "ქვეყანა",
    "Status" : "სტატუსი",
    "Created at" : "შეიქმნა",
    "Validate SSL certificate" : "SSL სერტიფიკატის ვალიდაცია",
    "Shared secret" : "გაზიარებული საიდუმლო",
    "STUN servers" : "STUN სერვერები",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN სერვერი როუტერს მიღმა მყოფი მონაწილეების ღია IP მისამართების დადგენისთვის.",
    "TURN server protocols" : "TURN სერვერის პროტოკოლები",
    "OK" : "კარგი",
    "Checking …" : "მოწმდება ...",
    "Confirm" : "დადასტურება",
    "Reset" : "საწყის მდოგმარეობაში დაბრუნება",
    "Back" : "უკან",
    "Cancel" : "უარყოფა",
    "Calendar" : "კალენდარი",
    "Attendees" : "დამსწრეები",
    "Save" : "შენახვა",
    "No results" : "შედეგები არაა",
    "Done" : "დასრულდა",
    "Waiting for others to join the call …" : "ზარში შემოსვლისთვის ველოდებით სხვებს …",
    "You can invite others in the participant tab of the sidebar" : "შეგიძლიათ სხვები მოიწვიოთ გვერდით ბარში, მონაწილებიის ტაბულით",
    "Share this link to invite others!" : "სხვების მოსაწვევად გააზიარეთ ეს ბმული!",
    "Copy link" : "ბმულის კოპირება",
    "Mute audio" : "ხმის ჩახშობა",
    "Disable video" : "ვიდეოს გათიშვა",
    "Enable video" : "ვიდეოს ამოქმედება",
    "You" : "თქვენ",
    "Show screen" : "ეკრანის ჩვენება",
    "Collapse" : "აკეცვა",
    "Favorite" : "რჩეული",
    "Hide details" : "დეტალების დამალვა",
    "Disable" : "გამორთვა",
    "Choose" : "აირჩიეთ",
    "Restricted" : "აკრძალული",
    "Personal" : "პირადი",
    "Yes" : "დიახ",
    "Password protection" : "პაროლით თავდაცვა",
    "Set a password" : "პაროლის დაყენება",
    "Edit" : "შეცვლა",
    "Delete" : "წაშლა",
    "Log content" : "ლოგის მოცულობა",
    "Notifications" : "შეტყობინებები",
    "Log in" : "შესვლა",
    "Mark as read" : "წაკითხულად მონიშვნა",
    "Mark as unread" : "წაუკითხავად მონიშვნა",
    "Remove from favorites" : "რჩეულებიდან ამოშლა",
    "Add to favorites" : "რჩეულებში დამატება",
    "Users" : "მომხმარებლები",
    "Groups" : "ჯგუფები",
    "None" : "არც ერთი",
    "Devices" : "მოწყობილობები",
    "Upload" : "ატვირთვა",
    "Files" : "ფაილები",
    "Message sent" : "წერილი გაგზავნილია",
    "Reply" : "პასუხი",
    "Translate" : "გადათარგმნეთ",
    "Dismiss" : "დათხოვნა",
    "Contact" : "კონტაქტი",
    "Today" : "დღეს",
    "Yesterday" : "გუშინ",
    "_%n day ago_::_%n days ago_" : ["%n დღის წინ","%n დღის წინ"],
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Create new poll" : "ახალი გამოკითხვის შექმნა",
    "Send" : "გაგზავნა",
    "Create poll" : "გამოკითხვის შექმნა",
    "Settings" : "პარამეტრები",
    "moderator" : "მოდერატორი",
    "Remove participant" : "მონაწილის ამოშლა",
    "Demote from moderator" : "ჩამოიქვეითება მოდერატორობისგან",
    "Promote to moderator" : "დაწინაურება მოდერატორობაზე",
    "Add users or groups" : "დაამატეთ მომხმარებლები ან ჯგუფები",
    "Participants" : "მონაწილეები",
    "Chat" : "ჩეთი",
    "Details" : "დეტალები",
    "Privacy" : "კონფიდენციალურობა",
    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
    "Search" : "ძიება",
    "Screensharing options" : "ეკრანების გაზიარების პარამეტრები",
    "Enable screensharing" : "ეკრანების გაზიარების ნების დართვა",
    "Screensharing requires the page to be loaded through HTTPS." : "ეკრანების გაზიარება საჭიროებს გვერდის HTTPS პროტოკოლით ჩატვირთვას.",
    "Sharing your screen only works with Firefox version 52 or newer." : "ეკრანის გაზიარება მოქმედია Firefox-ის მხოლოდ 52 ვერსიით ან უფრო ახლით.",
    "Screensharing extension is required to share your screen." : "ეკრანების გასაზიარებლად საჭიროა გაფართოება.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "ეკრანის გასაზიარებლად გამოიყენეთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი.",
    "An error occurred while starting screensharing." : "ეკრანის გაზიარებისას წარმოიშვა შეცდომა.",
    "Show your screen" : "თქვენი ეკრანის ჩვენება",
    "Stop screensharing" : "ეკრანის გაზიარების გათიშვა",
    "Grid view" : "ბადისებური ხედი",
    "Submit" : "გაგზავნა",
    "User" : "მომხმარებელი",
    "Password" : "პაროლი",
    "API token" : "API ტოკენი",
    "Login" : "ავტორიზაცია",
    "Nickname" : "ნიკნეიმი",
    "Client ID" : "კლიენტის ID",
    "Polls" : "გამოკითხვები",
    "Audio" : "აუდიო",
    "Other" : "სხვა",
    "Group" : "ჯგუფი",
    "Please reload the page." : "გთხოვთ გადატვირთოთ გვერდი.",
    "Default" : "საწყისი",
    "Access to microphone & camera is only possible with HTTPS" : "წვდომა მიკროფონთან და კამერასთან მხარდაჭერილია მხოლოდ HTTPS პროტოკოლით",
    "Access to microphone & camera was denied" : "წვდომა მიკროფონზე და კამერაზე აიკრძალა",
    "WebRTC is not supported in your browser" : "თქვენი ბრაუზერი WebRTC-ს არ უჭერს მხარს",
    "Please use a different browser like Firefox or Chrome" : "გთხოვთ გამოიყენოთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი",
    "Error while accessing microphone & camera" : "მიკროფონზე და კამერაზე წვდომისას წარმოიშვა შეცდომა",
    "The password is wrong. Try again." : "პაროლი არასწორია. სცადეთ ახლიდან.",
    "Android app" : "Android აპლიკაცია",
    "iOS app" : "iOS აპლიკაცია",
    "__language_name__" : "ქართული",
    "Tasks" : "დავალებები",
    "Notes" : "ჩანაწერები",
    "Loading" : "იტვირთება",
    "Close" : "დახურვა",
    "Password protect" : "პაროლით დაცვა",
    "TURN server" : "TURN სერვერი",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN სერვერი გამოიყენება ფაირვოლს უკან მყოფი მონაწილეების ტრეფიკის რწმუნებულებების გადასაცემად.",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "დიდი ინსტალაციებისთვის შესაძლებელია გარე სასიგნალო სერვერის გამოყენება. შიდა სიგნალის სერვერის გამოსაყენებლად დატოვეთ ცარიელი."
},
"nplurals=2; plural=(n!=1);");
